<h1 align="center">
  <p align="center">admindojo.org</p>
  <a href="https://admindojo.org"><img height="300" src="https://admindojo.org/img/dojo_round.png" alt="admindojo"></a>
</h1>

<p align="center">
  <a href="https://pypi.python.org/pypi/admindojo"><img src="https://img.shields.io/pypi/v/admindojo.svg" alt="pypi Version"></a>
  <a href="https://travis-ci.org/admindojo/admindojo-client"><img src="https://img.shields.io/travis/admindojo/admindojo-client.svg" alt="Travis Status"></a>
</p>

# Introduction

admindojo is a free, interactive Linux tutorial for (junior) sysadmins.
Using local virtual machines, admindojo provides real-world scenarios in real environments.

This repository contains the client that is used inside each training VM.

Visit [admindojo.org](https://admindojo.org/getting-started) for more information.


# Basic Usage

``admindojo start`` : Start training

``admindojo check`` : Run check and calculate score

``admindojo --help``: help


# License
Free software: MIT license

# Credits
- Package templating tool [https://github.com/audreyr/cookiecutter](ookiecutter)
- Package template [https://github.com/audreyr/cookiecutter-pypackage](audreyr/cookiecutter-pypackage)
